# python_project

Add an user interface for teh visualization of the results of pybacktestchain

## Installation

```bash
$ pip install 203_python_project_rc
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`203_python_project_rc` was created by Raphael Corchia. It is licensed under the terms of the MIT license.

## Credits

`203_python_project_rc` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
